﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Fw.Utility.UnifyResponse;
using RestSharp;

namespace Hotline.Api.Sdk
{
    public interface IHotlineClient
    {
        Task<ApiResponse<TResponse>> ExecuteAsync<TRequest, TResponse>(TRequest request, CancellationToken cancellationToken)
            where TRequest : HotlineRequest;
    }

    public abstract class HotlineRequest
    {
        public abstract string Path();
        public abstract Method HttpMethod();
    }

    public class HotlineClient : IHotlineClient, IDisposable
    {
        private readonly RestClient _client;

        public HotlineClient(string baseUrl, string apiKey, string apiSecret)
        {
            var options = new RestClientOptions(baseUrl)
            {
                Authenticator = new HotlineAuthenticator(baseUrl, apiKey, apiSecret)
            };
            _client = new RestClient(options);
        }

        public async Task<ApiResponse<TResponse>> ExecuteAsync<TRequest, TResponse>(TRequest request, CancellationToken cancellationToken) where TRequest : HotlineRequest
        {
            throw new NotImplementedException();
        }

        /// <summary>Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.</summary>
        public void Dispose()
        {
            _client?.Dispose();
            GC.SuppressFinalize(this);
        }
    }
}
